@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkPassThrough extends vtkPassInputTypeAlgorithm
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -35,6 +35,22 @@ public class vtkPassThrough extends vtkPassInputTypeAlgorithm
   public void DeepCopyInputOff()
     { DeepCopyInputOff_6(); }
 
+  private native void SetAllowNullInput_7(boolean id0);
+  public void SetAllowNullInput(boolean id0)
+    { SetAllowNullInput_7(id0); }
+
+  private native boolean GetAllowNullInput_8();
+  public boolean GetAllowNullInput()
+    { return GetAllowNullInput_8(); }
+
+  private native void AllowNullInputOn_9();
+  public void AllowNullInputOn()
+    { AllowNullInputOn_9(); }
+
+  private native void AllowNullInputOff_10();
+  public void AllowNullInputOff()
+    { AllowNullInputOff_10(); }
+
   public vtkPassThrough() { super(); }
 
   public vtkPassThrough(long id) { super(id); }
